require 'rubygems'
require 'net/ldap'

SAMPLE_SIZE = 400

#LDAP Settings
ldap = Net::LDAP.new
ldap.host = "ldap.andrew.cmu.edu"
ldap.port = 389
treebase = "ou=Person,dc=cmu,dc=edu"
attrs = %w[cn cmuandrewid cmustudentclass cmudepartment]

#Classes to search
classes = %w[Freshman Sophomore Junior Senior]

#File output
ug_list = File.new("ug_list.csv", "w+")
ug_random = File.new("ug_random.csv", "w+")

#Array of all undergrads
ugs = Array.new

#Nested for loops to get around 300 result limit of LDAP server
classes.each do |cl|
	for c in "A".."Z"
		filter = 	Net::LDAP::Filter.eq( "cmustudentclass", cl ) &
					Net::LDAP::Filter.eq( "cn", "#{c}*")

		ldap.search( :base => treebase, :filter => filter, :attributes => attrs ) do |entry|
			s = "#{entry.cn[0]},#{entry.cmuandrewid[0]},#{entry.cmustudentclass[0]},#{entry.cmudepartment[0]}\n"
			ug_list.write(s) #write string to master file
			ugs.push(s) #push string into array
		end
	end
end

#Get random sample
for i in 1..SAMPLE_SIZE
	#Generate a random number that is between 0 and the array size
	rnum = (rand * ugs.length).round
	
	ug_random.write(ugs[rnum]) #output to file
	ugs.delete_at(rnum) #remove string so we can't choose it again
end

#Close files
ug_list.close
ug_random.close